@@ -1,5 +1,5 @@
 (*
- *	Copyright (C) 2006 Vincent Hanquez <tab@snarc.org>
+ *	Copyright (C) 2006-2008 Vincent Hanquez <tab@snarc.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published
@@ -25,4 +25,4 @@ external file_fast: string -> t = "stub_sha256_file"
 
 end
 
-include Sha.Sha(Sha256ops)
+include Shacommon.Sha(Sha256ops)
