@@ -1,5 +1,5 @@
 (*
- *	Copyright (C) 2006 Vincent Hanquez <tab@snarc.org>
+ *	Copyright (C) 2006-2008 Vincent Hanquez <tab@snarc.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published
@@ -24,4 +24,4 @@ external to_hex: t -> string = "stub_sha512_to_hex"
 external file_fast: string -> t = "stub_sha512_file"
 end
 
-include Sha.Sha(Sha512ops)
+include Shacommon.Sha(Sha512ops)
