@@ -1,5 +1,5 @@
 (*
- *	Copyright (C) 2006 Vincent Hanquez <tab@snarc.org>
+ *	Copyright (C) 2006-2008 Vincent Hanquez <tab@snarc.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published
@@ -72,7 +72,15 @@ let _ =
 	let sha256 file = Sha256.to_hex (Sha256.file file) in
 	let sha512 file = Sha512.to_hex (Sha512.file file) in
 
-	let sha = match Filename.basename Sys.argv.(0) with
+	let basename = Filename.basename Sys.argv.(0) in
+	let prog =
+		if Sys.os_type = "Win32" then
+			try Filename.chop_extension basename
+			with Invalid_argument _ -> basename
+		else
+			basename
+		in
+	let sha = match prog with
 		| "sha512sum" -> sha512
 		| "sha256sum" -> sha256
 		| "sha1sum"   -> sha1
